@@ -197,12 +197,12 @@ class ChainlitXpanderDataLayer(BaseDataLayer):
         if not author:
             raise Exception("Thread author not found")
 
-        xpander = await make_async(XpanderClient)(
+        xpander = XpanderClient(
             api_key=getenv("AGENT_CONTROLLER_API_KEY", ""),
             base_url=getenv("AGENT_CONTROLLER_URL", ""),
             organization_id=author.get("organization_id"),
         )
-        await make_async(Memory.delete_thread_by_id)({"configuration": xpander.configuration}, thread_id=thread_id)
+        Memory.delete_thread_by_id({"configuration": xpander.configuration}, thread_id=thread_id)
         self.thread_authors_cache.pop(thread_id)
 
     async def list_threads(self, pagination: Pagination, filters: ThreadFilter) -> PaginatedResponse[ThreadDict]:
@@ -222,12 +222,12 @@ class ChainlitXpanderDataLayer(BaseDataLayer):
         
         organization_id = user.metadata['organization_id']
         agent_id = user.metadata['agent_id']
-        xpander = await make_async(XpanderClient)(
+        xpander = XpanderClient(
             api_key=getenv("AGENT_CONTROLLER_API_KEY", ""),
             base_url=getenv("AGENT_CONTROLLER_URL", ""),
             organization_id=organization_id,
         )
-        threads = await make_async(Memory.fetch_user_threads)(
+        threads = Memory.fetch_user_threads(
             agent={"configuration": xpander.configuration, "userDetails": {"id": filters.userId}}
         )
         
@@ -265,13 +265,13 @@ class ChainlitXpanderDataLayer(BaseDataLayer):
             ThreadDict: Thread details if found, else None.
         """
         user: User = cl.user_session.get("user")
-        xpander = await make_async(XpanderClient)(
+        xpander = XpanderClient(
             api_key=getenv("AGENT_CONTROLLER_API_KEY", ""),
             base_url=getenv("AGENT_CONTROLLER_URL", ""),
             organization_id=user.metadata.get("organization_id"),
         )
 
-        all_user_threads = await make_async(Memory.fetch_user_threads)(
+        all_user_threads = Memory.fetch_user_threads(
             agent={"configuration": xpander.configuration, "userDetails": {"id": user.identifier}}
         )
         thread_meta = next((trd for trd in all_user_threads if trd.id == thread_id), None)
@@ -311,12 +311,13 @@ class ChainlitXpanderDataLayer(BaseDataLayer):
         if not author or author == None:
             return
 
-        xpander = await make_async(XpanderClient)(
+        xpander = XpanderClient(
             api_key=getenv("AGENT_CONTROLLER_API_KEY", ""),
             base_url=getenv("AGENT_CONTROLLER_URL", ""),
             organization_id=author.get("organization_id"),
         )
-        await make_async(Memory.rename_thread_by_id)({"configuration": xpander.configuration}, thread_id=thread_id, name=name)
+        if name and isinstance(name, str) and len(name) != 0:
+            Memory.rename_thread_by_id({"configuration": xpander.configuration}, thread_id=thread_id, name=name)
 
     async def delete_user_session(self, id: str) -> bool:
         """
@@ -426,7 +427,7 @@ class ChainlitAdapter(SDKAdapter):
         """
         return cl.user_session.get("xpander_thread_id", None)
 
-    def add_task(
+    async def add_task(
         self,
         input: Any,
         files: Optional[List[Any]] = None,
@@ -476,7 +477,7 @@ class ChainlitAdapter(SDKAdapter):
                 self.agent.memory.update_messages(updated_thread)
 
         # Add the new task to the agent
-        super().add_task(input, files, use_worker, thread_id)
+        super().add_task(input=input, files=files, use_worker=use_worker, thread_id=thread_id)
 
         # Store the xpander.ai thread ID in the user session
         cl.user_session.set("xpander_thread_id", self.agent.execution.memory_thread_id)
@@ -638,7 +639,7 @@ class ChainlitAdapter(SDKAdapter):
                     tool_name = f"{self.agent.name} - Final Thoughts"
                     should_send_step = False
                 else:
-                    tool_name = graph_item.name
+                    tool_name = graph_item.name if graph_item else tool_name
                     
             elif is_agent_end_tool:
                 tool_name = f"Crafting final answer"
@@ -736,10 +737,6 @@ class ChainlitAdapter(SDKAdapter):
                     current_step.output = tool_call_result.result
                     current_step.language = "json"
                     
-                if tool_call_result.result == "STOP":
-                        current_step.name = f"Waiting for human approval ({tool_name})"
-                        current_step.output = None
-                
                 if should_send_step:
                     await current_step.update()
                 if is_agent_end_tool and not is_sub_agent:
